@@ -7,7 +7,7 @@ Attean::API::IDPJoinPlanner - Iterative dynamic programming query planning role
 
 =head1 VERSION
 
-This document describes Attean::API::IDPJoinPlanner version 0.032
+This document describes Attean::API::IDPJoinPlanner version 0.033
 
 =head1 SYNOPSIS
 
@@ -32,15 +32,16 @@ methods that consume the L<Attean::API::CostPlanner> role.
 
 =cut
 
-package Attean::API::QueryPlanner 0.032 {
-	use Types::Standard qw(CodeRef);
+package Attean::API::QueryPlanner 0.033 {
+	use Types::Standard qw(CodeRef Object);
 
 	use Moo::Role;
 	
 	requires 'plan_for_algebra'; # plan_for_algebra($algebra, $model, \@default_graphs)
+	has 'request_signer' => (is => 'rw', isa => Object);
 }
 
-package Attean::API::CostPlanner 0.032 {
+package Attean::API::CostPlanner 0.033 {
 	use Scalar::Util qw(refaddr);
 	use Types::Standard qw(CodeRef);
 
@@ -75,12 +76,12 @@ package Attean::API::CostPlanner 0.032 {
 	}
 }
 
-package Attean::API::JoinPlanner 0.032 {
+package Attean::API::JoinPlanner 0.033 {
 	use Moo::Role;
 	requires 'joins_for_plan_alternatives';
 }
 
-package Attean::API::NaiveJoinPlanner 0.032 {
+package Attean::API::NaiveJoinPlanner 0.033 {
 	use Math::Cartesian::Product;
 
 	use Moo::Role;
@@ -108,7 +109,7 @@ package Attean::API::NaiveJoinPlanner 0.032 {
 	}
 }
 
-package Attean::API::SimpleCostPlanner 0.032 {
+package Attean::API::SimpleCostPlanner 0.033 {
 	use Types::Standard qw(Int);
 	use Scalar::Util qw(blessed);
 
@@ -213,7 +214,7 @@ package Attean::API::SimpleCostPlanner 0.032 {
 	}
 }
 
-package Attean::API::IDPJoinPlanner 0.032 {
+package Attean::API::IDPJoinPlanner 0.033 {
 	use Encode qw(encode);
 	use Attean::RDF;
 	use LWP::UserAgent;
