@@ -8,7 +8,7 @@ Attean::Plan - Representation of SPARQL query plan operators
 
 =head1 VERSION
 
-This document describes Attean::Plan version 0.032
+This document describes Attean::Plan version 0.033
 
 =head1 SYNOPSIS
 
@@ -32,7 +32,7 @@ Evaluates a quad pattern against the model.
 
 =cut
 
-package Attean::Plan::Quad 0.032 {
+package Attean::Plan::Quad 0.033 {
 	use Moo;
 	use Scalar::Util qw(blessed reftype);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -137,7 +137,7 @@ Evaluates a join (natural-, anti-, or left-) using a nested loop.
 
 =cut
 
-package Attean::Plan::NestedLoopJoin 0.032 {
+package Attean::Plan::NestedLoopJoin 0.033 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use namespace::clean;
@@ -226,7 +226,7 @@ Evaluates a join (natural-, anti-, or left-) using a hash join.
 
 =cut
 
-package Attean::Plan::HashJoin 0.032 {
+package Attean::Plan::HashJoin 0.033 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use namespace::clean;
@@ -367,7 +367,7 @@ package Attean::Plan::HashJoin 0.032 {
 
 =cut
 
-package Attean::Plan::Construct 0.032 {
+package Attean::Plan::Construct 0.033 {
 	use Moo;
 	use List::MoreUtils qw(all);
 	use Types::Standard qw(Str ArrayRef ConsumerOf InstanceOf);
@@ -458,7 +458,7 @@ package Attean::Plan::Construct 0.032 {
 
 =cut
 
-package Attean::Plan::Describe 0.032 {
+package Attean::Plan::Describe 0.033 {
 	use Moo;
 	use Attean::RDF;
 	use List::MoreUtils qw(all);
@@ -544,7 +544,7 @@ named variable binding.
 
 =cut
 
-package Attean::Plan::EBVFilter 0.032 {
+package Attean::Plan::EBVFilter 0.033 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ConsumerOf);
@@ -603,7 +603,7 @@ ordering.
 
 =cut
 
-package Attean::Plan::Merge 0.032 {
+package Attean::Plan::Merge 0.033 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(Str ArrayRef ConsumerOf);
@@ -632,7 +632,7 @@ Evaluates a set of sub-plans, returning the union of results.
 
 =cut
 
-package Attean::Plan::Union 0.032 {
+package Attean::Plan::Union 0.033 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use namespace::clean;
@@ -703,7 +703,7 @@ expressions, binding the produced values to new variables.
 
 =cut
 
-package Attean::Plan::Extend 0.032 {
+package Attean::Plan::Extend 0.033 {
 	use Moo;
 	use Encode;
 	use UUID::Tiny ':std';
@@ -1365,7 +1365,7 @@ hash of already-seen results.
 
 =cut
 
-package Attean::Plan::HashDistinct 0.032 {
+package Attean::Plan::HashDistinct 0.033 {
 	use Moo;
 	use namespace::clean;
 	
@@ -1393,7 +1393,7 @@ filtering out sequential duplicates.
 
 =cut
 
-package Attean::Plan::Unique 0.032 {
+package Attean::Plan::Unique 0.033 {
 	use Moo;
 	use namespace::clean;
 	
@@ -1428,7 +1428,7 @@ number of results ("offset") and limiting the total number of returned results
 
 =cut
 
-package Attean::Plan::Slice 0.032 {
+package Attean::Plan::Slice 0.033 {
 	use Moo;
 	use Types::Standard qw(Int);
 	use namespace::clean;
@@ -1469,7 +1469,7 @@ of variable bindings in each result.
 
 =cut
 
-package Attean::Plan::Project 0.032 {
+package Attean::Plan::Project 0.033 {
 	use Moo;
 	with 'Attean::API::BindingSubstitutionPlan', 'Attean::API::UnaryQueryTree';
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -1546,7 +1546,7 @@ sorting is applied.
 
 =cut
 
-package Attean::Plan::OrderBy 0.032 {
+package Attean::Plan::OrderBy 0.033 {
 	use Moo;
 	use Types::Standard qw(HashRef ArrayRef InstanceOf Bool Str);
 	use Scalar::Util qw(blessed);
@@ -1629,9 +1629,13 @@ Evaluates a SPARQL query against a remote endpoint.
 
 =cut
 
-package Attean::Plan::Service 0.032 {
+package Attean::Plan::Service 0.033 {
 	use Moo;
-	use Types::Standard qw(ConsumerOf Bool Str);
+	use Types::Standard qw(ConsumerOf Bool Str InstanceOf);
+	use Encode qw(encode);
+	use Scalar::Util qw(blessed);
+	use URI::Escape;
+	use Attean::SPARQLClient;
 	use namespace::clean;
 
 	with 'Attean::API::Plan', 'Attean::API::UnaryQueryTree';
@@ -1639,6 +1643,8 @@ package Attean::Plan::Service 0.032 {
 	has 'endpoint' => (is => 'ro', isa => ConsumerOf['Attean::API::TermOrVariable'], required => 1);
 	has 'silent' => (is => 'ro', isa => Bool, default => 0);
 	has 'sparql' => (is => 'ro', isa => Str, required => 1);
+	has 'user_agent' => (is => 'rw', isa => InstanceOf['LWP::UserAgent']);
+	has 'request_signer' => (is => 'rw');
 
 	sub plan_as_string {
 		my $self	= shift;
@@ -1651,7 +1657,20 @@ package Attean::Plan::Service 0.032 {
 	sub impl {
 		my $self	= shift;
 		my $model	= shift;
-		die __PACKAGE__ . " unimplemented";
+
+		my $endpoint	= $self->endpoint->value;
+		my $sparql		= $self->sparql;
+		my $silent		= $self->silent;
+		my %args		= (
+			endpoint		=> $endpoint,
+			silent			=> $silent,
+			request_signer	=> $self->request_signer,
+		);
+		$args{user_agent}	= $self->user_agent if ($self->user_agent);
+		my $client		= Attean::SPARQLClient->new(%args);
+		return sub {
+			return $client->query($sparql);
+		};
 	}
 }
 
@@ -1661,7 +1680,7 @@ Returns a constant set of results.
 
 =cut
 
-package Attean::Plan::Table 0.032 {
+package Attean::Plan::Table 0.033 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -1726,7 +1745,7 @@ L<Attean::ListIterator>, the size of that iterator will be used.
 
 =cut
 
-package Attean::Plan::Iterator 0.032 {
+package Attean::Plan::Iterator 0.033 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf Int);
 	use namespace::clean;
@@ -1790,7 +1809,7 @@ package Attean::Plan::Iterator 0.032 {
 
 =cut
 
-package Attean::Plan::ALPPath 0.032 {
+package Attean::Plan::ALPPath 0.033 {
 	use Moo;
 	use Attean::TreeRewriter;
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -1942,7 +1961,7 @@ package Attean::Plan::ALPPath 0.032 {
 	}
 }
 
-package Attean::Plan::ZeroOrOnePath 0.032 {
+package Attean::Plan::ZeroOrOnePath 0.033 {
 	use Moo;
 	use Attean::TreeRewriter;
 	use Types::Standard qw(ArrayRef ConsumerOf);
@@ -2041,7 +2060,7 @@ results were produced by evaluating the sub-plan.
 
 =cut
 
-package Attean::Plan::Exists 0.032 {
+package Attean::Plan::Exists 0.033 {
 	use Moo;
 	use Types::Standard qw(ArrayRef ConsumerOf);
 	use namespace::clean;
@@ -2071,7 +2090,7 @@ package Attean::Plan::Exists 0.032 {
 
 =cut
 
-package Attean::Plan::Aggregate 0.032 {
+package Attean::Plan::Aggregate 0.033 {
 	use Moo;
 	use Encode;
 	use UUID::Tiny ':std';
@@ -2316,7 +2335,7 @@ package Attean::Plan::Aggregate 0.032 {
 	}
 }
 
-package Attean::Plan::Sequence 0.032 {
+package Attean::Plan::Sequence 0.033 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2341,7 +2360,7 @@ package Attean::Plan::Sequence 0.032 {
 	}
 }
 
-package Attean::Plan::Clear 0.032 {
+package Attean::Plan::Clear 0.033 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2378,7 +2397,7 @@ package Attean::Plan::Clear 0.032 {
 	}
 }
 
-package Attean::Plan::Drop 0.032 {
+package Attean::Plan::Drop 0.033 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf ArrayRef);
@@ -2413,7 +2432,7 @@ package Attean::Plan::Drop 0.032 {
 	}
 }
 
-package Attean::Plan::TripleTemplateToModelQuadMethod 0.032 {
+package Attean::Plan::TripleTemplateToModelQuadMethod 0.033 {
 	use Moo;
 	use Scalar::Util qw(blessed);
 	use Types::Standard qw(ConsumerOf Str ArrayRef HashRef);
@@ -2489,7 +2508,7 @@ package Attean::Plan::TripleTemplateToModelQuadMethod 0.032 {
 	}
 }
 
-package Attean::Plan::Load 0.032 {
+package Attean::Plan::Load 0.033 {
 	use Moo;
 	use Encode;
 	use LWP::UserAgent;
