@@ -19,7 +19,7 @@ use Encode qw(encode encode_utf8);
 use Getopt::Long;
 use Regexp::Common qw /URI/;
 use Scalar::Util qw(blessed reftype);
-use List::Util qw(all);
+use List::MoreUtils qw(all);
 use Test::Modern;
 use Text::CSV;
 use Try::Tiny;
@@ -53,8 +53,7 @@ sub manifest_paths {
 	}
 	
 	my $manifest	= File::Spec->catfile($dir, 'manifest.ttl');
-	my $manifestall	= File::Spec->catfile($dir, 'manifest-all.ttl');
-	return grep { -r $_ } ($manifest, $manifestall);
+	return grep { -r $_ } ($manifest);
 }
 
 
@@ -70,7 +69,7 @@ Test::Roo::top_test 'SPARQL 1.1 tests' => sub {
 # 		warn "Manifest: " . $m->as_string . "\n" if ($self->debug);
 		my ($list)	= $model->objects( $m, iri("${MF}entries") )->elements;
 		unless (blessed($list)) {
-			warn "No mf:entries found for manifest " . $m->as_string . "\n" if ($self->debug);
+			warn "No mf:entries found for manifest " . $m->as_string . "\n";
 		}
 		my @tests	= $model->get_list( $self->default_graph, $list )->elements;
 		foreach my $test (@tests) {
