@@ -8,19 +8,17 @@ use Attean;
 use Attean::RDF;
 use AtteanX::Parser::SPARQL;
 use Attean::SimpleQueryEvaluator;
-use Test::Attean::TestSimpleQueryEvaluator;
-use Test::Attean::TestIDPQueryPlanner;
 
 use Carp;
 use HTTP::Request;
 use HTTP::Response;
 use HTTP::Message::PSGI;
 use Data::Dumper;
-use Encode qw(encode encode_utf8 decode_utf8);
+use Encode qw(encode encode_utf8);
 use Getopt::Long;
 use Regexp::Common qw /URI/;
 use Scalar::Util qw(blessed reftype);
-use List::Util qw(all);
+use List::MoreUtils qw(all);
 use Test::Modern;
 use Text::CSV;
 use Try::Tiny;
@@ -75,8 +73,8 @@ sub setup {
 	$self->default_graph(iri('http://graph/'));
 
 	warn 'setting up sparql test harness' if ($self->debug);
-	my @manifests_iris	= $self->manifest_paths();
-	unless (scalar(@manifests_iris)) {
+	my @manifests	= $self->manifest_paths();
+	unless (scalar(@manifests)) {
 		my $dir		= $self->tests_dir;
 		plan skip_all => "No manifest files found in $dir";
 		exit(0);
@@ -85,32 +83,14 @@ sub setup {
 	my $model	= $self->memory_model();
 	my $class	= Attean->get_parser("turtle") || die "Failed to load parser for 'turtle'";
 
-	my %loaded;
-	
-	my @manifests;
-	my @load	= map { iri("file://" . File::Spec->rel2abs($_)) } @manifests_iris;
-	while (scalar(@load)) {
-		foreach my $iri (@load) {
-			warn "Loading " . $iri->value . "\n" if ($self->debug);
-			$loaded{ $iri->value }++;
-		}
-		$model->load_urls_into_graph($self->default_graph, @load);
-		@load	= ();
+	my @load	= map { iri("file://" . File::Spec->rel2abs($_)) } @manifests;
+	$model->load_urls_into_graph($self->default_graph, @load);
 
-		warn "done parsing manifests" if $self->debug;
-		$self->model($model);
-		my $subjects = $model->subjects( iri("${RDF}type"), iri("${MF}Manifest") );
-		my @manifest_matches	= $subjects->elements;
-		push(@manifests, @manifest_matches);
-	
-		foreach my $m (@manifest_matches) {
-			my @list_heads	= $model->objects( $m, iri("${MF}include") )->elements;
-			my @elements	= map { $model->get_list(undef, $_)->elements() } @list_heads;
-			push(@load, grep { not exists($loaded{$_->value}) } @elements);
-		}
-	}
-	
-	$self->manifests(\@manifests);
+	warn "done parsing manifests" if $self->debug;
+	$self->model($model);
+	my $subjects = $model->subjects( iri("${RDF}type"), iri("${MF}Manifest") );
+	my @manifest_matches	= $subjects->elements;
+	$self->manifests(\@manifest_matches);
 }
 
 sub syntax_test {
@@ -199,7 +179,7 @@ sub update_eval_test {
 	my ($req)		= $model->objects( $test, iri("${MF}requires") )->elements;
 	my ($approved)	= $model->objects( $test, iri("${DAWGT}approval") )->elements;
 	my ($queryd)	= $model->objects( $action, iri("${UT}request") )->elements;
-	my @data		= $model->objects( $action, iri("${UT}data") )->elements;
+	my ($data)		= $model->objects( $action, iri("${UT}data") )->elements;
 	my @gdata		= $model->objects( $action, iri("${UT}graphData") )->elements;
 	
 	if ($self->strict_approval) {
@@ -225,9 +205,7 @@ sub update_eval_test {
 	if ($self->debug) {
 		warn "### test     : " . $test->value . "\n";
 		warn "# sparql     : $q\n";
-		foreach my $data (@data) {
-			warn "# data       : " . $data->value . "\n" if (blessed($data));
-		}
+		warn "# data       : " . $data->value . "\n" if (blessed($data));
 		warn "# graph data : " . $_->value . "\n" for (@gdata);
 		warn "# result     : " . $result->value . "\n";
 		warn "# requires   : " . $req->value . "\n" if (blessed($req));
@@ -237,17 +215,15 @@ sub update_eval_test {
 
 	warn "constructing model...\n" if ($self->debug);
 	my $test_model	= $self->test_model();
-	foreach my $data (@data) {
-		eval {
-			if (blessed($data)) {
-				$test_model->load_urls_into_graph($self->default_graph, $data);
-			}
-		};
-		if ($@) {
-			fail($test->value);
-			print "# died: " . $test->value . ": $@\n";
-			return;
+	eval {
+		if (blessed($data)) {
+			$test_model->load_urls_into_graph($self->default_graph, $data);
 		}
+	};
+	if ($@) {
+		fail($test->value);
+		print "# died: " . $test->value . ": $@\n";
+		return;
 	}
 	foreach my $gdata (@gdata) {
 		my ($data)	= ($model->objects( $gdata, iri("${UT}data") )->elements)[0] || ($model->objects( $gdata, iri("${UT}graph") )->elements)[0];
@@ -358,61 +334,6 @@ sub update_eval_test {
 	warn "ok\n" if ($self->debug);
 }
 
-sub construct_data {
-	my $self	= shift;
-	my $model	= shift;
-	my $action	= shift;
-	my ($queryd)	= $model->objects( $action, iri("${RQ}query") )->elements;
-	my @data		= $model->objects( $action, iri("${RQ}data") )->elements;
-	my @gdata		= $model->objects( $action, iri("${RQ}graphData") )->elements;
-	my @sdata		= $model->objects( $action, iri("${RQ}serviceData") )->elements;
-	my @cdata		= $model->objects( $action, iri("${RQ}constructDataFile") )->elements;
-	my ($fnode)		= $model->objects( $action, iri("${RQ}format") )->elements;
-	my $format		= blessed($fnode) ? $fnode->value : 'text/turtle';
-
-	my $uri					= URI->new( $queryd->value );
-	my $filename			= $uri->file;
-	my (undef,$base,undef)	= File::Spec->splitpath( $filename );
-	$base					= "file://${base}";
-	warn "Loading SPARQL query from file $filename" if ($self->debug);
-	my $sparql				= do { local($/) = undef; open(my $fh, '<', $filename) or do { warn("$!: $filename"); return }; binmode($fh, ':utf8'); <$fh> };
-	
-	my $test_model	= $self->test_model();
-	foreach my $data (@data) {
-		if (blessed($data)) {
-			$test_model->load_urls_into_graph($self->default_graph, $data);
-		}
-	}
-	foreach my $g (@gdata) {
-		my $start = $test_model->size;
-		$test_model->load_urls_into_graph($g, $g);
-		my $end	= $test_model->size;
-		unless ($start < $end) {
-			warn "*** Loading file did not result in any new quads: " . $g;
-		}
-	}
-	foreach my $n (@cdata) {
-		my ($bytes, $format)	= $self->construct_data($model, $n);
-		my $p					= Attean->get_parser(media_type => $format)->new();
-		my $iter				= $p->parse_iter_from_bytes($bytes);
-		$test_model->add_iter($iter->as_quads($self->default_graph));
-	}
-	
-	print STDERR "ok\n" if ($self->debug);
-
-	if ($self->debug) {
-		my $q	= $sparql;
-		$q		=~ s/([\x{256}-\x{1000}])/'\x{' . sprintf('%x', ord($1)) . '}'/eg;
-		warn $q;
-	}
-	
-	my ($iter, $type)		= $self->get_actual_results( $filename, $test_model, $sparql, $base, $model, \@sdata );
-	my $sclass				= Attean->get_serializer(media_type => $format);
-	my $s					= $sclass->new();
-	my $bytes				= $s->serialize_iter_to_bytes($iter);
-	return ($bytes, $format);
-}
-
 sub query_eval_test {
 	my $self		= shift;
 	my $model		= shift;
@@ -424,10 +345,9 @@ sub query_eval_test {
 	my ($req)		= $model->objects( $test, iri("${MF}requires") )->elements;
 	my ($approved)	= $model->objects( $test, iri("${DAWGT}approval") )->elements;
 	my ($queryd)	= $model->objects( $action, iri("${RQ}query") )->elements;
-	my @data		= $model->objects( $action, iri("${RQ}data") )->elements;
+	my ($data)		= $model->objects( $action, iri("${RQ}data") )->elements;
 	my @gdata		= $model->objects( $action, iri("${RQ}graphData") )->elements;
 	my @sdata		= $model->objects( $action, iri("${RQ}serviceData") )->elements;
-	my @cdata		= $model->objects( $action, iri("${RQ}constructDataFile") )->elements;
 	
 	if ($self->strict_approval) {
 		unless ($approved) {
@@ -450,15 +370,12 @@ sub query_eval_test {
 	my $q			= $sparql;
 	$q				=~ s/\s+/ /g;
 	if ($self->debug) {
-		warn "### test           : " . $test->value . "\n";
-		warn "# sparql           : $q\n";
-		foreach my $data (@data) {
-			warn "# data             : " . ($data->value =~ s#file://##r) . "\n" if (blessed($data));
-		}
-		warn "# graph data       : " . ($_->value =~ s#file://##r) . "\n" for (@gdata);
-		warn "# constructed data : " . ($_->value =~ s#file://##r) . "\n" for (@cdata);
-		warn "# result           : " . ($result->value =~ s#file://##r) . "\n";
-		warn "# requires         : " . ($req->value =~ s#file://##r) . "\n" if (blessed($req));
+		warn "### test     : " . $test->value . "\n";
+		warn "# sparql     : $q\n";
+		warn "# data       : " . ($data->value =~ s#file://##r) . "\n" if (blessed($data));
+		warn "# graph data : " . ($_->value =~ s#file://##r) . "\n" for (@gdata);
+		warn "# result     : " . ($result->value =~ s#file://##r) . "\n";
+		warn "# requires   : " . ($req->value =~ s#file://##r) . "\n" if (blessed($req));
 	}
 	
 STRESS:	foreach (1 .. $count) {
@@ -466,24 +383,11 @@ STRESS:	foreach (1 .. $count) {
 		my $test_model	= $self->test_model();
 		my $next_stress	= 0;
 		try {
-			foreach my $data (@data) {
-				if (blessed($data)) {
-					$test_model->load_urls_into_graph($self->default_graph, $data);
-				}
+			if (blessed($data)) {
+				$test_model->load_urls_into_graph($self->default_graph, $data);
 			}
 			foreach my $g (@gdata) {
-				my $start = $test_model->size;
 				$test_model->load_urls_into_graph($g, $g);
-				my $end	= $test_model->size;
-				unless ($start < $end) {
-					warn "*** Loading file did not result in any new quads: " . $g;
-				}
-			}
-			foreach my $n (@cdata) {
-				my ($bytes, $format)	= $self->construct_data($model, $n);
-				my $p					= Attean->get_parser(media_type => $format)->new();
-				my $iter				= $p->parse_iter_from_bytes($bytes);
-				$test_model->add_iter($iter->as_quads($self->default_graph));
 			}
 		} catch {
 			fail($test->value);
@@ -511,7 +415,7 @@ STRESS:	foreach (1 .. $count) {
 				{
 					local($::DEBUG)	= 1;
 					print STDERR "getting actual results... " if ($self->debug);
-					($actual, $type)		= $self->get_actual_results( $filename, $test_model, $sparql, $base, $model, \@sdata );
+					($actual, $type)		= $self->get_actual_results( $filename, $test_model, $sparql, $base );
 					print STDERR "ok\n" if ($self->debug);
 				}
 			
@@ -537,45 +441,12 @@ STRESS:	foreach (1 .. $count) {
 	}
 }
 
-sub mock_endpoints {
-	my $self			= shift;
-	my $mock			= shift;
-	my $model	= shift;
-	my $sdata			= shift;
-	
-	foreach my $sd (@$sdata) {
-		my ($e)		= $model->objects( $sd, iri("${RQ}endpoint") )->elements;
-		my @data	= $model->objects( $sd, iri("${RQ}data") )->elements;
-		my @gdata	= $model->objects( $sd, iri("${RQ}graphData") )->elements;
-
-		my $endpoint	= $e->value;
-		my $test_model	= $self->test_model();
-		foreach my $data (@data) {
-			if (blessed($data)) {
-				$test_model->load_urls_into_graph($self->default_graph, $data);
-			}
-		}
-		foreach my $g (@gdata) {
-			my $start = $test_model->size;
-			$test_model->load_urls_into_graph($g, $g);
-			my $end	= $test_model->size;
-			unless ($start < $end) {
-				warn "*** Loading file did not result in any new quads: " . $g;
-			}
-		}
-		$mock->register_test_endpoint($endpoint, [$test_model, $self->default_graph]);
-	}
-}
-
 sub get_actual_results {
-	my $self			= shift;
-	my $filename		= shift;
-	my $model			= shift;
-	my $sparql			= shift;
-	my $base			= shift;
-	my $manifest_model	= shift;
-	my $sdata			= shift;
-	
+	my $self		= shift;
+	my $filename	= shift;
+	my $model		= shift;
+	my $sparql		= shift;
+	my $base		= shift;
 	my $bytes	= encode_utf8($sparql);
 
 	my $s 			= AtteanX::Parser::SPARQL->new(base => $base);
@@ -608,20 +479,16 @@ sub get_actual_results {
 	my $results;
 	if ($self->use_idp_planner) {
 		my $default_graphs	= [$self->default_graph];
-		my $planner	= Test::Attean::TestIDPQueryPlanner->new();
-		$self->mock_endpoints($planner, $manifest_model, $sdata);
+		my $planner	= Attean::IDPQueryPlanner->new();
 		my $plan	= $planner->plan_for_algebra($algebra, $model, $default_graphs);
 		if ($self->debug) {
 			warn "Walking plan:\n";
 			warn $plan->as_string;
 		}
-		$results	= eval { $plan->evaluate($model) };
-		warn $@ if $@;
+		$results	= $plan->evaluate($model);
 	} else {
-		my $e		= Test::Attean::TestSimpleQueryEvaluator->new( model => $model, default_graph => $self->default_graph );
-		$self->mock_endpoints($e, $manifest_model, $sdata);
-		$results	= eval { $e->evaluate($algebra, $self->default_graph) };
-		warn $@ if $@;
+		my $e		= Attean::SimpleQueryEvaluator->new( model => $model, default_graph => $self->default_graph );
+		$results	= $e->evaluate($algebra, $self->default_graph);
 	}
 	my $count	= 1;
 	
@@ -636,7 +503,7 @@ sub get_actual_results {
 			$type	= 'boolean';
 		}
 	}
-
+	
 	$self->print_results("Actual results", \$results) if ($self->results);
 	return ($results, $type);
 	
@@ -792,10 +659,7 @@ sub compare_results {
 			$actual	= $actual->map($mapper->binding_mapper);
 		}
 
-		my $ok		= eval { ok( $eqtest->equals( $actual, $expected ), $test ) or diag($eqtest->error) };
-		if ($@) {
-			diag($@);
-		}
+		my $ok		= ok( $eqtest->equals( $actual, $expected ), $test ) or diag($eqtest->error);
 		$self->record_result('evaluation', $ok, $test);
 		return $ok;
 	} elsif ($actual->does('Attean::API::TermIterator')) {
